@@ -319,7 +319,7 @@ void feh_event_handle_stdin()
 	char stdin_buf[2];
 	static char is_esc = 0;
 	KeySym keysym = NoSymbol;
-	if (read(STDIN_FILENO, &stdin_buf, 1) == -1) {
+	if (read(STDIN_FILENO, &stdin_buf, 1) <= 0) {
 		control_via_stdin = 0;
 		if (isatty(STDIN_FILENO) && getpgrp() == (tcgetpgrp(STDIN_FILENO))) {
 			weprintf("reading a command from stdin failed - disabling control via stdin");
@@ -359,7 +359,7 @@ void feh_event_handle_stdin()
 	else
 		keysym = XStringToKeysym(stdin_buf);
 
-	if (window_num)
+	if (window_num && keysym)
 		feh_event_handle_generic(windows[0], is_esc * Mod1Mask, keysym, 0);
 
 	is_esc = 0;
@@ -603,7 +603,7 @@ void feh_event_handle_generic(winwidget winwid, unsigned int state, KeySym keysy
 	}
 	else if (feh_is_kp(EVENT_zoom_in, state, keysym, button)) {
 		winwid->old_zoom = winwid->zoom;
-		winwid->zoom = winwid->zoom * 1.25;
+		winwid->zoom = winwid->zoom * opt.zoom_rate;
 
 		if (winwid->zoom > ZOOM_MAX)
 			winwid->zoom = ZOOM_MAX;
@@ -617,7 +617,7 @@ void feh_event_handle_generic(winwidget winwid, unsigned int state, KeySym keysy
 	}
 	else if (feh_is_kp(EVENT_zoom_out, state, keysym, button)) {
 		winwid->old_zoom = winwid->zoom;
-		winwid->zoom = winwid->zoom * 0.80;
+		winwid->zoom = winwid->zoom / opt.zoom_rate;
 
 		if (winwid->zoom < ZOOM_MIN)
 			winwid->zoom = ZOOM_MIN;
